@@ -4,6 +4,8 @@
 Draupnir : Ancestral protein sequence reconstruction using a tree-structured Ornstein-Uhlenbeck variational autoencoder
 =======================
 """
+import sys
+#sys.path.append("./draupnir/src/draupnir")
 import draupnir.utils as DraupnirUtils
 import warnings
 from collections import namedtuple
@@ -49,7 +51,7 @@ def available_datasets(print_dict = False):
                 "aminopeptidase":"Amino Peptidase",
                 "PF00096":"PF00096 protein kinases"}
     return datasets,datasets_full_names
-def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_file=None,tree_file=None,alignment_file=None):
+def create_draupnir_dataset(name,use_custom,script_dir,build=False,fasta_file=None,tree_file=None,alignment_file=None):
     """In:
     :param str name: Dataset name
     :param bool use_custom: True (uses a custom dataset, located in datasets/custom/"folder_name" ) or False (uses a Draupnir default dataset (used in the publication))
@@ -76,8 +78,8 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
         root_sequence_name = available_datasets()[0][name]
         full_name = available_datasets()[1][name]
         storage_folder = os.path.abspath(os.path.join(os.path.dirname(__file__), "data")) #changed from "datasets/default"
-        dir_name = '{}/{}'.format(storage_folder,name)
-        dict_urls = {
+        if not os.listdir('{}/{}'.format(storage_folder,name)):
+            dict_urls = {
                 "aminopeptidase":"https://drive.google.com/drive/folders/1fLsOJbD1hczX15NW0clCgL6Yf4mnx_yl?usp=sharing",
                 "benchmark_randall_original_naming":"https://drive.google.com/drive/folders/1oE5-22lqcobZMIguatOU_Ki3N2Fl9b4e?usp=sharing",
                 "Coral_all":"https://drive.google.com/drive/folders/1IbfiM2ww5PDcDSpTjrWklRnugP8RdUTu?usp=sharing",
@@ -97,26 +99,12 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                 "simulations_src_sh3_3":"https://drive.google.com/drive/folders/13xLOqW2ldRNm8OeU-bnp9DPEqU1d31Wy?usp=sharing"
 
             }
-        if os.path.isdir(dir_name):
-            if not os.listdir(dir_name):
-                print("Directory is empty")
-                os.remove(dir_name)
-                print("Data directory is missing. Downloading, this might take a while. If you see an error like \n"
-                      " 'Cannot retrieve the public link of the file. You may need to change the permission to <Anyone with the link>, or have had many accesses', \n"
-                      "just wait, too many requests have been made to the google drive folder \n"
-                      "Otherwise just download the data sets manually from the google drive urls : \n {}".format(
-                    dict_urls[name]))
-                gdown.download_folder(dict_urls[name], output='{}/{}'.format(storage_folder, name), quiet=True,
-                                      use_cookies=False, remaining_ok=True)
-
-
-            else:
-                print("Dataset is ready in the folder!")
-        else:
-            print("Data directory is missing. Downloading, this might take a while. If you see an error like \n"
+            print("Default data is missing. Downloading, this might take a while. If you see an error like \n"
                   " 'Cannot retrieve the public link of the file. You may need to change the permission to <Anyone with the link>, or have had many accesses', \n"
                   "just wait, too many requests have been made to the google drive folder \n"
                   "Otherwise just download the data sets manually from the google drive urls : \n {}".format(dict_urls[name]))
+
+
             gdown.download_folder(dict_urls[name], output='{}/{}'.format(storage_folder,name),quiet=True, use_cookies=False,remaining_ok=True)
 
 
@@ -303,7 +291,7 @@ def create_draupnir_dataset(name,use_custom,script_dir,args,build=False,fasta_fi
                                              tree_file=tree_file,
                                              alignment_file=alignment_file,
                                              fasta_file=fasta_file,
-                                             aa_probs=args.aa_probs,
+                                             aa_probs=21,
                                              rename_internal_nodes=True,
                                              storage_folder=storage_folder)
         else:
